<!-- Do not edit this file. It is automatically generated by API Documenter. -->

[Home](./index.md) &gt; [@genesislcap/foundation-entity-management](./foundation-entity-management.md) &gt; [EntityManagement](./foundation-entity-management.entitymanagement.md)

## EntityManagement class

Main class which defines the entity management functionality

**Signature:**

```typescript
export declare class EntityManagement extends EntityManagement_base 
```
**Extends:** EntityManagement\_base

## Remarks

Connects to a backend resource and wraps up a grid which is populated with entities from that resource. The different interactions that the user can perform with the entities can be configured, examples being able to update and delete entities.

## Example

Example of using the entity management system to handle counterparties

```
<entity-management
  resourceName="ALL_COUNTERPARTYS"
  title="Counterparty Management"
  updateEvent="EVENT_COUNTERPARTY_MODIFY"
  deleteEvent="EVENT_COUNTERPARTY_DELETE"
  createEvent="EVENT_COUNTERPARTY_INSERT"
></entity-management>
```
Where:<br /> - the title of the grid is `Counterparty Management`<br /> - the name of the resource in the database to manage is `ALL_COUNTERPARTYS`<br /> - the name of the event handler for update events is `EVENT_COUNTERPARTY_MODIFY`<br /> - the name of the event handler for create events is `EVENT_COUNTERPARTY_INSERT`<br /> - the name of the event handler for delete events is `EVENT_COUNTERPARTY_DELETE`<br />

## Properties

|  Property | Modifiers | Type | Description |
|  --- | --- | --- | --- |
|  [asyncAdd](./foundation-entity-management.entitymanagement.asyncadd.md) |  | boolean | Whether to use the <code>applyTransactionAsync</code> function for \*add\* transactions |
|  [asyncRemove](./foundation-entity-management.entitymanagement.asyncremove.md) |  | boolean | Whether to use the <code>applyTransactionAsync</code> function for \*remove\* transactions |
|  [asyncUpdate](./foundation-entity-management.entitymanagement.asyncupdate.md) |  | boolean | Whether to use the <code>applyTransactionAsync</code> function for \*update\* transactions |
|  [columns](./foundation-entity-management.entitymanagement.columns.md) |  | ColDef\[\] | Array which holds the column definitions. |
|  [connect](./foundation-entity-management.entitymanagement.connect.md) | <code>protected</code> | Connect | DI connect object which is used to interact with the backend. |
|  [createEvent](./foundation-entity-management.entitymanagement.createevent.md) |  | string | Name of the event handler on the Genesis server which handles creating an entity |
|  [createFormUiSchema](./foundation-entity-management.entitymanagement.createformuischema.md) |  | UiSchema |  |
|  [crudActionMenuName](./foundation-entity-management.entitymanagement.crudactionmenuname.md) |  | string | The label of the crud action menu |
|  [crudMenuPosition](./foundation-entity-management.entitymanagement.crudmenuposition.md) |  | CrudMenuPosition | Determines where the buttons will appear |
|  [crudMenuStyle](./foundation-entity-management.entitymanagement.crudmenustyle.md) |  | ActionsMenuStyle | Determines the style of the buttons |
|  [crudMenuWrapper](./foundation-entity-management.entitymanagement.crudmenuwrapper.md) |  | any | The Id of the crud buttons wrapper element |
|  [datasourceConfig](./foundation-entity-management.entitymanagement.datasourceconfig.md) |  | [DatasourceConfiguration](./foundation-entity-management.datasourceconfiguration.md) | The configuration which is used when interacting with the resource on the backend |
|  [datasourceType](./foundation-entity-management.entitymanagement.datasourcetype.md) |  | DatasourceType | If set to 'server' it will enable Server-Side Row Model and use <code>grid-pro-server-side-datasource</code> for the grid of the <code>entity-list</code> sub-component. By default <code>grid-pro-client-side-datasource</code> will be used. |
|  [defaultEntityValues](./foundation-entity-management.entitymanagement.defaultentityvalues.md) |  | Record&lt;string, unknown&gt; | The default values to populate the form with when the user is adding an entity |
|  [deleteEvent](./foundation-entity-management.entitymanagement.deleteevent.md) |  | string | Name of the event handler on the Genesis server which handles deleting the entity |
|  [editedEntity](./foundation-entity-management.entitymanagement.editedentity.md) |  | Record&lt;string, unknown&gt; | Disables the form while enabled to stop the user dispatching a large number of duplicate events |
|  [editEntityModal](./foundation-entity-management.entitymanagement.editentitymodal.md) |  | Modal |  |
|  [editModalVisible](./foundation-entity-management.entitymanagement.editmodalvisible.md) |  | boolean |  |
|  [enableCellFlashing](./foundation-entity-management.entitymanagement.enablecellflashing.md) |  | boolean | If false, will disable cell flashing for all cells by default, unless otherwise defined in custom colDef |
|  [enableFilterBar](./foundation-entity-management.entitymanagement.enablefilterbar.md) |  | boolean |  |
|  [enableRowFlashing](./foundation-entity-management.entitymanagement.enablerowflashing.md) |  | boolean | If true, will enable row flashing for all rows for <code>add</code> transactions |
|  [enableSearchBar](./foundation-entity-management.entitymanagement.enablesearchbar.md) |  | boolean | This attribute controls whether to enable the search-bar. |
|  [entityLabel](./foundation-entity-management.entitymanagement.entitylabel.md) |  | string | Label for the entity which has usages such as being shown in the title of the modal wen editing the entity |
|  [formRenderers](./foundation-entity-management.entitymanagement.formrenderers.md) |  | RendererEntry\[\] | Array with renderers used by foundation-forms |
|  [formUiSchema](./foundation-entity-management.entitymanagement.formuischema.md) |  | UiSchema |  |
|  [gridOptions](./foundation-entity-management.entitymanagement.gridoptions.md) |  | GridOptions | GridOptions to be passed down from application |
|  [hasSelectedEntity](./foundation-entity-management.entitymanagement.hasselectedentity.md) | <code>readonly</code> | boolean | Determines whether there is a selected entity |
|  [headerCaseType](./foundation-entity-management.entitymanagement.headercasetype.md) |  | GridProCaseType | The case type to use for the header names. If not set, the default CONSTANT\_CASE will be used. |
|  [headerTempalate](./foundation-entity-management.entitymanagement.headertempalate.md) | <code>readonly</code> | import("@microsoft/fast-element").ViewTemplate&lt;[EntityManagement](./foundation-entity-management.entitymanagement.md)<!-- -->, any&gt; |  |
|  [hideDelete](./foundation-entity-management.entitymanagement.hidedelete.md) |  | boolean |  |
|  [hideEdit](./foundation-entity-management.entitymanagement.hideedit.md) |  | boolean |  |
|  [isServerSideDatasource](./foundation-entity-management.entitymanagement.isserversidedatasource.md) | <code>readonly</code> | boolean |  |
|  [modalFormTitle](./foundation-entity-management.entitymanagement.modalformtitle.md) | <code>readonly</code> | string | Getter for the title of the modal form |
|  [modalFormType](./foundation-entity-management.entitymanagement.modalformtype.md) |  | ModalFormType | The type of form that is currently being displayed in the modal |
|  [modalPosition](./foundation-entity-management.entitymanagement.modalposition.md) |  | 'centre' \| 'left' \| 'right' | Determines where the modal dialog will appear on screen |
|  [persistColumnStateKey](./foundation-entity-management.entitymanagement.persistcolumnstatekey.md) |  | string | This attribute controls whether and how the entity manager stores the state of the columns when the user edits them. Omit this attribute to disable the functionality, set it to a unique value to enable it. |
|  [prefix](./foundation-entity-management.entitymanagement.prefix.md) |  | string | Name of the design system prefix that will be used in renderers. |
|  [readEvent](./foundation-entity-management.entitymanagement.readevent.md) |  | string |  |
|  [readEventFn](./foundation-entity-management.entitymanagement.readeventfn.md) |  | (...args: any\[\]) =&gt; {} |  |
|  [readonly](./foundation-entity-management.entitymanagement.readonly.md) |  | boolean |  |
|  [resourceName](./foundation-entity-management.entitymanagement.resourcename.md) |  | string | Name of the backend resource which contain the entities to manage |
|  [rowSelection](./foundation-entity-management.entitymanagement.rowselection.md) |  | string | This attribute allows you to change row-selection to 'single' or 'multiple' which will allow you to select single or multiple rows. |
|  [searchBarConfig](./foundation-entity-management.entitymanagement.searchbarconfig.md) |  | AvailableOption\[\] |  |
|  [selectedEntity](./foundation-entity-management.entitymanagement.selectedentity.md) |  | Record&lt;string, unknown&gt; | Reference to the currently selected entity from the grid. |
|  [shouldHideDeleteInColumn](./foundation-entity-management.entitymanagement.shouldhidedeleteincolumn.md) | <code>readonly</code> | boolean | Determines whether the button delete should be hidden in the column |
|  [shouldHideEditInColumn](./foundation-entity-management.entitymanagement.shouldhideeditincolumn.md) | <code>readonly</code> | boolean | Determines whether the button edit should be hidden in the column |
|  [sizeColumnsToFit](./foundation-entity-management.entitymanagement.sizecolumnstofit.md) |  | boolean |  |
|  [submitting](./foundation-entity-management.entitymanagement.submitting.md) |  | boolean |  |
|  [title](./foundation-entity-management.entitymanagement.title.md) |  | string | Title of the grid |
|  [updateEvent](./foundation-entity-management.entitymanagement.updateevent.md) |  | string | Name of the event handler on the Genesis server which handles updating the entity |
|  [updateFormUiSchema](./foundation-entity-management.entitymanagement.updateformuischema.md) |  | UiSchema |  |

## Methods

|  Method | Modifiers | Description |
|  --- | --- | --- |
|  [closeModal()](./foundation-entity-management.entitymanagement.closemodal.md) |  |  |
|  [confirmDelete()](./foundation-entity-management.entitymanagement.confirmdelete.md) |  |  |
|  [criteriaChanged(e)](./foundation-entity-management.entitymanagement.criteriachanged.md) |  |  |
|  [deepClone()](./foundation-entity-management.entitymanagement.deepclone.md) |  | Override the deepClone method to ensure that observable attributes are cloned |
|  [disconnectedCallback()](./foundation-entity-management.entitymanagement.disconnectedcallback.md) |  |  |
|  [editModalVisibleChanged()](./foundation-entity-management.entitymanagement.editmodalvisiblechanged.md) |  |  |
|  [emitCrud(action)](./foundation-entity-management.entitymanagement.emitcrud.md) |  | Emit the CRUD event for the selected entity |
|  [getTitleBasedOnActionOrType(actionOrType)](./foundation-entity-management.entitymanagement.gettitlebasedonactionortype.md) |  | The helper function to determine the title of the modal form or button based on the action or type |
|  [hasContentInSlot(slotName)](./foundation-entity-management.entitymanagement.hascontentinslot.md) |  | Checks if a slot contains any content. |
|  [requestChanged(e)](./foundation-entity-management.entitymanagement.requestchanged.md) |  |  |
|  [searchBarDataserver(options)](./foundation-entity-management.entitymanagement.searchbardataserver.md) |  |  |
|  [searchBarReqServer(options)](./foundation-entity-management.entitymanagement.searchbarreqserver.md) |  |  |
|  [searchChanged(event)](./foundation-entity-management.entitymanagement.searchchanged.md) |  |  |
|  [selectionChanged(event)](./foundation-entity-management.entitymanagement.selectionchanged.md) |  | The event handler for when the selection changes in the grid. |
|  [submitEntityChanges(e)](./foundation-entity-management.entitymanagement.submitentitychanges.md) |  | Event handler for when the user submits the action for the currently open form, either editing or adding the entity |
|  [submitFailureNotification(e)](./foundation-entity-management.entitymanagement.submitfailurenotification.md) |  |  |

